@@ -38,10 +38,11 @@ int main(int argc, char *argv[])
         cout << "--operation import" << endl;
         cout << "--operation export" << endl;
         cout << "--operation list" << endl;
+        cout << "--operation tasks-clear-done" << endl;
 
         return -1;
     }
-
+    cout << "operation is:" << operation.toLocal8Bit().constData() << endl;
     ok = do_operation(args, operation);
 
     if (!ok){
